#
# spec file for package retext
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           retext
Version:        7.0.4
Release:        lp151.1.1
Summary:        Simple editor for Markdown and reStructuredText
License:        GPL-3.0-or-later
Group:          Productivity/Text/Editors
Url:            https://github.com/retext-project/retext
Source:         https://github.com/retext-project/retext/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  python3
BuildRequires:  python3-Markdown
BuildRequires:  python3-Markups >= 2.0
BuildRequires:  python3-devel
BuildRequires:  python3-docutils
BuildRequires:  python3-qt5
BuildRequires:  rsvg-view
BuildRequires:  update-desktop-files
Requires:       python3-Markdown
Requires:       python3-Markups >= 2.0
Requires:       python3-docutils
Requires:       python3-pyenchant
Requires:       python3-qt5
Requires(post): hicolor-icon-theme
Requires(post): update-desktop-files
Requires(postun): hicolor-icon-theme
Requires(postun): update-desktop-files
Recommends:     python3-Pygments
Provides:       ReText = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
ReText is simple text editor that supports Markdown and reStructuredText
markup languages. It is written in Python using PyQt libraries.

%prep
%setup -q
dos2unix LICENSE_GPL

%build
python3 setup.py build

%install
python3 setup.py install --root=%{buildroot} --prefix=%{_prefix}

mkdir -pv %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/
mkdir -pv %{buildroot}%{_datadir}/%{name}/
mkdir -pv %{buildroot}%{_datadir}/applications/

cp -r icons/*.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/
ICONSIZE="16 22 32 48 64 128 256"
pushd %{buildroot}%{_datadir}/icons/hicolor/
for i in $ICONSIZE; do
  mkdir -pv ${i}x${i}/apps/
  rsvg-convert -h $i -w $i scalable/apps/%{name}.svg -o ${i}x${i}/apps/%{name}.png
done
popd

%suse_update_desktop_file %{buildroot}%{_datadir}/applications/me.mitya57.ReText.desktop

%fdupes %{buildroot}%{_prefix}

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%defattr(-,root,root)
%doc changelog.md README.md configuration.md
%license LICENSE_GPL
%{_bindir}/%{name}
%{python3_sitelib}/ReText/
%{python3_sitelib}/*
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/%{name}/
%{_datadir}/applications/*.desktop
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/*appdata.xml

%changelog
* Wed Jan  2 2019 badshah400@gmail.com
- Update to version 7.0.4:
  * Improved editor performance (gh#retext-project/retext#360).
  * Support for Python-Markdown 3.0.
  * Updated translations.
* Tue Oct  2 2018 Marguerite Su <i@marguerite.su>
- Update to version 7.0.0
  * The highlighter was improved. It got support for
    reStructuredText links, field lists and for Markdown and
    reStructuredText code spans.
  * Added the text replace feature.
  * Added the experimental renderer based on Qt WebEngine, in
    addition to the existing Qt WebKit one.
  * It is now possible to insert new table rows by pressing Return
    in "Table editing mode". Additionally, pressing Shift+Return
    will create a new row and a separator line
  * The WebKit and WebEngine previewers can now detect links
    to local HTML files and open the corresponding source file
    in new tab if those are found.
  * ReText can now automatically detect encoding of files using
    the chardet module when it is installed.
  * Several new configuration options were added.
- upstream fixed boo#1040433
  * ReText can't start from KDE Application launcher (kickoff)
    but can from command line because sys.stdin.read() led
    to a blockage
- drop retext-add-appdata-description.patch, upstreamed
* Tue Jan 10 2017 mpluskal@suse.com
- Fix typo in patch
* Sat Jan  7 2017 badshah400@gmail.com
- Add retext-add-appdata-description.patch to add a helpful
  description to the appdata file; changes taken from upstream.
* Sat May 14 2016 mpluskal@suse.com
- Update to version 6.0.0
  * The live preview now automatically scrolls to match its
    sition with the editor (only for Markdown).
  * Markup conversion is now performed in a background process,
    proving responsiveness of the editor.
  * Images can now be copied and pasted into ReText (contributed by
    Bart Clephas).
  * Added a button to quickly close the search bar.
  * Added basic CSS styling for tables.
  * Replaced the tags box with the new “Formatting” box for
    Markdown (contributed by Donato Marrazzo).
  * Hitting return twice now ends the Markdown list.
  * ReText now depends on version 2.0 or higher of pymarkups.
  * The QtWebKit dependency is now optional (though still
    recommended).
- Spec file cleanups
  * Update dependencies
  * Use pretty name for source archive
  * Disable testsuite as it requires connection to Xserver
* Mon Dec 21 2015 badshah400@gmail.com
- Update to version 5.3.0:
  + Tabs are now reorderable.
  + All colors used in editor and highlighter are now configurable
    via the configuration file.
  + Links referencing other source files are now opened in ReText
    as new tabs.
  + Code refactoring: some code moved to the new tab.py module,
    and some old hacks dropped.
  + The ReText logo is now installed to the data directory.
  + Appstream metadata updated to a newer format.
  + The desktop file no longer hardcodes the executable path.
- Changes from version 5.2.0:
  + ReText now tries to load the icon theme from system settings
    if Qt cannot auto-detect it.
  + Added a GUI option to change the editor font.
  + Added appdata file for appstream.
- Drop custom desktop file and use upstream bundled file.
- Package appdata.
- Add post(un) scriptlets for updating icon theme cache and
  desktop database.
- Project moved to github, update URL and source location
  accordingly.
* Tue Jun 30 2015 mailaender@opensuse.org
- update to version 5.1.0
- enable test suite
* Mon Jun  8 2015 mailaender@opensuse.org
- update to version 5.0.2
* Tue Jan  6 2015 kinfoo.dev@gmail.com
- recommend Python Pygments for syntax highlight
* Fri Dec 19 2014 mailaender@opensuse.org
- update to version 5.0.1
* Sat Jul 26 2014 mailaender@opensuse.org
- update to version 5.0.0
* Sat Jun 14 2014 mailaender@opensuse.org
- update to version 4.1.3
* Wed Apr 16 2014 mailaender@opensuse.org
- update version 4.1.2
- added GPG file verification
* Sat Sep 21 2013 mailaender@opensuse.org
- update version 4.1.1
  * Added configuration dialog
  * Added current line highlighting and line numbers support
  * Added support for PyQt5 and PySide libraries
  * Use new signals/slots syntax
  * Added option to select file encoding
  * Dropped support for Python 2 and support for running
    without WebKit installed
- adhere to https://en.opensuse.org/SourceUrls
* Sun Feb 24 2013 i@marguerite.su
- add link to %%{_bindir}/%%{name}
- correct dependency name python-Markups
* Sat Feb  2 2013 i@marguerite.su
- update version 4.0.0
  * Switch to pymarkups backend
  * Switch to python3 by default
  * Split retext.py to smaller files
  * MathJax support
  * Tab now inserts 4 spaces by default
  * Automatic indentation of new lines
  * External links are now opened in a web browser by default
  * Support for per-document CSS stylesheets
* Tue Jul 31 2012 i@marguerite.su
- update version 3.1.0
  * Spell checker suggestions
  * Markup-specifing highlighting
  * Re-written parser & document-type logic
  * Lots of code clean-up
* Mon May 21 2012 i@marguerite.su
- update to 3.0.3
  * Python 3 support
  * Improved highlighter
  * Export extensions
  * Recent files menu
  * Spell checking improvements
  * Shortcuts for formatting
  * WebKit engine improvements
* Sat Feb 18 2012 i@marguerite.su
- update to 3.0beta1
* Thu Dec 29 2011 i@marguerite.su
- update to 2.1.3
* Fri Nov 25 2011 pascal.bleser@opensuse.org
- initial version (2.1.2)
